Package: nestable
Type: Package
Title: Collapsible 'HTML' Tables from Hierarchical Data
Version: 0.1.1
Authors@R: person("Derek", "Underwood", email = "dereku@gmail.com",
    role = c("aut", "cre"))
Description: Creates collapsible, expandable 'HTML' tables from hierarchical
    data. Supports data frame input with multi-level grouping, custom column
    formatters, bottom-up rollup aggregation, and CSS-variable-based theming.
    Works in 'Shiny' applications, R Markdown, 'Quarto', and the 'RStudio' Viewer.
License: GPL (>= 3)
URL: https://github.com/derekunderwood/nestable
BugReports: https://github.com/derekunderwood/nestable/issues
Encoding: UTF-8
RoxygenNote: 7.3.3
Imports: htmltools (>= 0.5.0)
Suggests: shiny (>= 1.7.0), testthat (>= 3.0.0)
NeedsCompilation: no
Packaged: 2026-06-16 01:03:03 UTC; derek
Author: Derek Underwood [aut, cre]
Maintainer: Derek Underwood <dereku@gmail.com>
Repository: CRAN
Date/Publication: 2026-06-16 02:20:02 UTC
Built: R 4.6.0; ; 2026-06-16 08:09:36 UTC; unix
