% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/nestable.R
\name{nestableOutput}
\alias{nestableOutput}
\alias{renderNestable}
\title{Shiny UI output for a nestable table}
\usage{
nestableOutput(outputId, ...)

renderNestable(expr, env = parent.frame(), quoted = FALSE)
}
\arguments{
\item{outputId}{The output variable name.}

\item{...}{Additional arguments passed to \code{\link[shiny:htmlOutput]{shiny::uiOutput()}}.}

\item{expr}{An expression returning a \code{\link[=nestable]{nestable()}} widget.}

\item{env}{The environment in which to evaluate \code{expr}.}

\item{quoted}{Logical. Is \code{expr} already quoted? Default \code{FALSE}.}
}
\value{
A Shiny UI element.

A Shiny render function.
}
\description{
Use with \code{\link[=renderNestable]{renderNestable()}} in the server. These are thin wrappers over
\code{\link[shiny:htmlOutput]{shiny::uiOutput()}} and \code{\link[shiny:renderUI]{shiny::renderUI()}} — no \code{htmlwidgets} dependency
is required.
}
